import { Component, OnInit, HostListener, ViewEncapsulation } from '@angular/core';
import { SSTLayoutService } from '../sst-layout.service';

import { faBars, faAngleLeft } from '@fortawesome/free-solid-svg-icons';

@Component({
  selector: 'sst-full-layout',
  template: `
  <div class="layout"
    [class.nav-minimized]="sstLayoutService.isNavBarMinimized$ | async"
    [class.nav-hidden]="sstLayoutService.isNavBarHidden$ | async"
    [class.nav-mobile]="sstLayoutService.isNavBarMobile$ | async"
    (click)="handleLayoutClick($event)"
    >
    <div class="layout-nav">
      <div class="nav-top">
        <a class="nav-top-logo" routerLink="/"></a>
        <button class="nav-hide" (click)="handleToggleHidden()">
          <fa-icon [icon]="faBars"></fa-icon>
        </button>
      </div>
      <div class="nav-middle">
        <sst-menu></sst-menu>
      </div>
      <div class="nav-bottom">
        <button class="nav-toggle" (click)="handleToggleMinimize()">
          <fa-icon class="toggle-icon" [icon]="faAngleLeft"></fa-icon>
        </button>
      </div>
    </div>
    <div class="layout-container">
      <div class="container-top">
          <div class="top-title container-fluid">
            <sst-search></sst-search>
          </div>
          <div class="top-right">
            <sst-profile></sst-profile>
          </div>
      </div>
      <div class="container-content">
        <router-outlet></router-outlet>
      </div>
    </div>
  </div>
  `,
  styleUrls: ['./sst-full-layout.component.scss'],
  encapsulation: ViewEncapsulation.None
})
export class SSTFullLayoutComponent implements OnInit {

  faBars = faBars;
  faAngleLeft = faAngleLeft;

  public menuItens = [];
  private navVisiblilityStatus = 0;

  constructor(
    public sstLayoutService: SSTLayoutService
  ) {}

  ngOnInit() {
    this.onResize();
  }

  @HostListener('document:keypress', ['$event'])
  onKeyPress(event) {
    if ( (event.metaKey || event.ctrlKey) && event.key === 'b' ) {
      this.navVisiblilityStatus++;
      switch ( this.navVisiblilityStatus ) {
        case 1:
          return this.sstLayoutService.minimizeNav();
        case 2:
          return this.sstLayoutService.hiddenNav();
        default:
          this.navVisiblilityStatus = 0;
          return this.sstLayoutService.showNav();
      }
    }
  }

  @HostListener('window:resize')
  onResize() {
    if ( window.matchMedia('(max-width: 600px)').matches ) {
      this.sstLayoutService.hiddenNav();
      this.sstLayoutService.setMobileNav(true);
    } else {
      this.sstLayoutService.showNav();
      this.sstLayoutService.setMobileNav(false);
    }
  }

  handleLayoutClick(event) {
    if ( event.target.classList.contains('nav-mobile') ) {
      this.sstLayoutService.hiddenNav();
    }
  }

  handleToggleMinimize() {
    this.sstLayoutService.toggleMinimiseNav();
  }

  handleToggleHidden() {
    this.sstLayoutService.toggleHiddenNav();
  }
}
