import { Injectable } from '@angular/core';
import { BehaviorSubject } from 'rxjs';

@Injectable({
  providedIn: 'root'
})
export class SSTLayoutService {

  private isNavBarMinimizedSubject = new BehaviorSubject<boolean>(false);
  public isNavBarMinimized$ = this.isNavBarMinimizedSubject.asObservable();

  private isNavBarHiddenSubject = new BehaviorSubject<boolean>(false);
  public isNavBarHidden$ = this.isNavBarHiddenSubject.asObservable();

  private isNavBarMobileSubject = new BehaviorSubject<boolean>(false);
  public isNavBarMobile$ = this.isNavBarMobileSubject.asObservable();

  constructor() { }

  public toggleMinimiseNav() {
    this.isNavBarMinimizedSubject.next(!this.isNavBarMinimizedSubject.getValue());
  }

  public toggleHiddenNav() {
    this.isNavBarHiddenSubject.next(!this.isNavBarHiddenSubject.getValue());
  }

  public minimizeNav() {
    this.isNavBarMinimizedSubject.next(true);
    this.isNavBarHiddenSubject.next(false);
  }
  public hiddenNav() {
    this.isNavBarHiddenSubject.next(true);
    this.isNavBarMinimizedSubject.next(false);
  }
  public showNav() {
    this.isNavBarHiddenSubject.next(false);
    this.isNavBarMinimizedSubject.next(false);
  }

  public setMobileNav( isMobile: boolean = false ) {
    this.isNavBarMobileSubject.next(isMobile);
  }

  get isNavBarMobile() {
    return this.isNavBarMobileSubject.getValue();
  }

}
