import { Injectable } from '@angular/core';
import { SSTMenuItem } from './sst-menu.interface';
import { BehaviorSubject } from 'rxjs';
import { SSTAuthorizationService } from '@southsystem/authorization';

@Injectable({
  providedIn: 'root'
})
export class SSTMenuConfig {
  items: SSTMenuItem[] = [];
}

@Injectable({
  providedIn: 'root'
})
export class SSTMenuService {

  private menuSubject = new BehaviorSubject<SSTMenuItem[]>([]);
  public menuItems$ = this.menuSubject.asObservable();

  constructor(
    private sstAuthorizationService: SSTAuthorizationService,
    private menuConfig: SSTMenuConfig
  ) {
    this.menuSubject.next(this.authorizedItems(this.menuConfig.items));
  }

  public setMenuItems(menuItems: SSTMenuItem[]) {
    this.menuSubject.next(this.authorizedItems(menuItems));
  }

  private authorizedItems(menuItems: SSTMenuItem[]): SSTMenuItem[] {
    return menuItems.filter( item =>  {
      if ( item.children) {
        item.children = this.authorizedItems(item.children);
      }
      return item.roles ? this.sstAuthorizationService.checkRoles(item.roles) : true;
    });
  }

}
