import { SSTProfileItem } from './sst-profile.interface';
import { SSTProfileService } from './sst-profile.service';
import { faAngleDown, faAngleUp, faUser } from '@fortawesome/free-solid-svg-icons';
import { Component, OnInit } from '@angular/core';
import { SSTAuthenticationService } from '@southsystem/authentication';
import { Observable } from 'rxjs';
import { pluck } from 'rxjs/operators';
import { SSTAvatarService } from '@southsystem/avatar';

@Component({
  selector: 'sst-profile',
  template: `
  <div class="sst-profile" [class.expanded]="expanded">
    <div class="avatar">
      <fa-icon [icon]="avatar" [hidden]="avatarImage"></fa-icon>
      <div class="profile-pic" [hidden]="!avatarImage" [style.backgroundImage]="avatarImage | styleImage"></div>
    </div>
    <div class="user-name">
      {{name$ | async}}
    </div>
    <a class="profile-button" (click)="toggleExpand()"  href="javascript:void(0)">
      <div *ngIf="expanded == true">
        <fa-icon [icon]="faAngleUp"></fa-icon>
      </div>
      <div *ngIf="expanded == false">
        <fa-icon [icon]="faAngleDown"></fa-icon>
      </div>
    </a>
    <div [hidden]="!expanded" (clickoutside)="hide()" class="profile-drop">
      <sst-avatar></sst-avatar>
      <hr />
      <ul>
        <li>
          {{name$ | async}}
        </li>
        <li>
          {{eMail$ | async}}
        </li>
        <li>
        <hr />
        </li>
        <li>
          <a href="#" (click)="onLogout($event)" i18n="@@profile_logout">Logout</a>
        </li>
      </ul>
    </div>
  </div>
  `,
  styleUrls: ['./sst-profile.component.scss']
})
export class SSTProfileComponent implements OnInit {

  public expanded = false;
  public profileOtions$: Observable<SSTProfileItem[]>;
  public avatar = faUser;
  public name$: Observable<string>;
  public eMail$: Observable<string>;
  public avatarImage = undefined;

  faAngleUp = faAngleUp;
  faAngleDown = faAngleDown;

  constructor(
    public sstAuth: SSTAuthenticationService,
    public sstProfileService: SSTProfileService,
    public sstAvatarService: SSTAvatarService
  ) {
    this.name$ = this.sstAuth.userInfo$.pipe(pluck('username'));
    this.profileOtions$ = this.sstProfileService.profileItems$;
    this.eMail$ = this.sstAuth.userInfo$.pipe(pluck('email'));
    this.sstAvatarService.getAvatar();
  }

  ngOnInit() {
    this.sstAvatarService.picObservable$.subscribe(event => {
      this.avatarImage = event;
    });
  }


  toggleExpand() {
    this.expanded = !this.expanded;
  }

  hide() {
    this.expanded = false;
  }

  onLogout(event) {
    event.preventDefault();
    this.sstAuth.logout();
  }

}
